@@ -72,7 +72,7 @@ class _Decoratable:
 
 
 class Transformer(_Decoratable, ABC, Generic[_Leaf_T, _Return_T]):
-    """Transformers work bottom-up (or depth-first), starting with visiting the leaves and working 
+    """Transformers work bottom-up (or depth-first), starting with visiting the leaves and working
     their way up until ending at the root of the tree.
 
     For each node visited, the transformer will call the appropriate method (callbacks), according to the
@@ -83,7 +83,7 @@ class Transformer(_Decoratable, ABC, Generic[_Leaf_T, _Return_T]):
 
     If the transformer cannot find a method with the right name, it will instead call ``__default__``, which by
     default creates a copy of the node.
-    
+
     To discard a node, return Discard (``lark.visitors.Discard``).
 
     ``Transformer`` can do anything ``Visitor`` can do, but because it reconstructs the tree,
@@ -520,7 +520,7 @@ def v_args(inline: bool = False, meta: bool = False, tree: bool = False, wrapper
 
     Parameters:
         inline (bool, optional): Children are provided as ``*args`` instead of a list argument (not recommended for very long lists).
-        meta (bool, optional): Provides two arguments: ``children`` and ``meta`` (instead of just the first)
+        meta (bool, optional): Provides two arguments: ``meta`` and ``children`` (instead of just the latter)
         tree (bool, optional): Provides the entire tree as the argument, instead of the children.
         wrapper (function, optional): Provide a function to decorate all methods.
 
@@ -532,6 +532,12 @@ def v_args(inline: bool = False, meta: bool = False, tree: bool = False, wrapper
                 def add(self, left, right):
                     return left + right
 
+                @v_args(meta=True)
+                def mul(self, meta, children):
+                    logger.info(f'mul at line {meta.line}')
+                    left, right = children
+                    return left * right
+
 
             class ReverseNotation(Transformer_InPlace):
                 @v_args(tree=True)
